@@ -1,5 +1,9 @@
 
-from scrapy_box.middlewares.proxymiddleware import RandomProxyDownloaderMiddleware
+from scrapy_box.middlewares.proxymiddleware import \
+    RandomProxyDownloaderMiddleware, \
+    SplashProxyDownloaderMiddleware, \
+    SplashRetryProxyMiddleware
+
 from scrapy_box.middlewares.retrymiddleware import ErrorRedirectMiddleware, ErrorResponseMiddleware
 from scrapy_box.pipelines.mongo import MongoBatchInsertPipeline
 from scrapy_box.pipelines.mysql import MysqlInsertPipeline, MysqlUpdatePipeline
