@@ -54,23 +54,21 @@ class RandomProxyDownloaderMiddleware(object):
 
 
 class SplashProxyDownloaderMiddleware(object):
-    def __init__(self, proxy_addr, splash_url):
+    def __init__(self, proxy_addr):
         self.proxy_addr = proxy_addr
-        self.splash_url = splash_url
 
     @classmethod
     def from_crawler(cls, crawler):
         proxy_addr = crawler.settings.get('PROXY_ADDR')
-        splash_url = crawler.settings.get('SPLASH_URL')
-        if proxy_addr is None or splash_url is None or not proxy_addr.startswith('http'):
+        if proxy_addr is None or not proxy_addr.startswith('http'):
             raise NotConfigured
 
-        return cls(proxy_addr, splash_url)
+        return cls(proxy_addr)
 
     @defer.inlineCallbacks
     def process_request(self, request, spider):
         proxy = yield self.get_proxy()
-        if not request.url.startswith(self.splash_url):
+        if request.meta.get('_splash_processed') is None:
             logger.debug('using proxy %s for request %s' % (proxy, request.meta['splash']['args']['url']))
             request.meta['splash']['args']['proxy'] = 'http://%(ip)s:%(port)s' % proxy
 
